<td style="vertical-align: middle;">
    <div class="input-group">
        <input type="checkbox" class="object-list-checkbox" id="{{ item_id }}-object-list-checkbox"
            value="{{ item_id }}" style="margin: 0 auto"/>
    </div>
</td>