.sorting_none.dark
{
    background-image:url("../images/sort_both.png");
    background-repeat: no-repeat;
    background-position: center right;
}

.sorting_asc.dark
{
    background-image:url("../images/sort_asc.png");
    background-repeat: no-repeat;
    background-position: center right;
}

.sorting_desc.dark
{
    background-image:url("../images/sort_desc.png");
    background-repeat: no-repeat;
    background-position: center right;
}

.sorting_none.light
{
    background-image:url("../images/sort_both_light.png");
}

.sorting_asc.light
{
    background-image:url("../images/sort_asc_light.png");
}

.sorting_desc.light
{
    background-image:url("../images/sort_desc_light.png");
}

.sortable_th
{
    border: 1px solid #ddd;
    cursor: default;
}

.sortable_th span {
    cursor: pointer;
}
